@@ -5,14 +5,16 @@ from tqdm import tqdm
 from torch import Tensor
 from typing import List
 from typing import Tuple
+from cftool.array import to_torch
+from cftool.array import to_device
 
-from .utils import predict_folder
-from ..data import SSLTestTransform
-from ..data import InferenceImageFolderData
-from ..pipeline import SimplePipeline
+from ..utils import predict_folder
+from ..pipeline import CVPipeline
+from ...protocol import IImageExtractor
+from ...protocol import ImageFolderLatentResponse
+from ....data import SSLTestTransform
+from ....data import InferenceImageFolderData
 from ....constants import LATENT_KEY
-from ....misc.toolkit import to_torch
-from ....misc.toolkit import to_device
 from ....misc.toolkit import eval_context
 
 try:
@@ -21,8 +23,8 @@ except:
     to_rgb = None
 
 
-class DINOExtractor:
-    def __init__(self, m: SimplePipeline, img_size: int, *, to_gray: bool = False):
+class DINOExtractor(IImageExtractor):
+    def __init__(self, m: CVPipeline, img_size: int, *, to_gray: bool = False):
         if to_rgb is None:
             raise ValueError("`carefree-cv` is needed for `DINOExtractor`")
         self.m = m
@@ -52,7 +54,7 @@ class DINOExtractor:
         batch_size: int,
         num_workers: int = 0,
         use_tqdm: bool = True,
-    ) -> Tuple[Tensor, List[str]]:
+    ) -> ImageFolderLatentResponse:
         results = predict_folder(
             self.m,
             src_folder,
@@ -61,8 +63,7 @@ class DINOExtractor:
             transform=self.transform,
             use_tqdm=use_tqdm,
         )
-        latent = to_torch(results.outputs[LATENT_KEY])
-        return latent, results.img_paths
+        return ImageFolderLatentResponse(results.outputs[LATENT_KEY], results.img_paths)
 
     def get_folder_logits(
         self,
